# HARFANG Contributors

(sorted alphabetically by surname)

* Vincent Cruz
* Camille Dudognon
* Robert Ewbank
* François Gutherz
* Emmanuel Julien
* Eric Kernin
* Elie Michel
* Thomas "Scorpheus" Simonnet
* Tommo Zhou